<?php


class WPML_ST_Page_URL_Preprocessor {
	/**
	 * @var array
	 */
	private $black_list = array(
		'paged',
		'page',
		's',
		'orderby',
		'order',
		// toolset parameters
		'wpv_column_sort_id',
		'wpv_column_sort_dir',
		'wpv_sort_orderby',
		'wpv_sort_order',
		'wpv_sort_orderby_as',
		'wpv_paged',
		'wpv_paged_preload_reach',
		'wpv_view_count',
		'wpv_filter_submit',
		'wpv_post_search',
		'wpv_taxonomy_search',
	);

	/**
	 * @param string $url
	 *
	 * @return string
	 */
	public function process_url( $url ) {
		if ( empty( $url ) ) {
			return $url;
		}

		$url = $this->process_path( $url );
		$url = $this->process_query( $url );

		return $url;
	}

	/**
	 * @param string $url
	 *
	 * @return string
	 */
	private function process_path( $url ) {
		$path = parse_url( $url, PHP_URL_PATH );
		$path = ltrim( $path, '/' );

		if ( empty( $path ) ) {
			return $url;
		}

		$params = explode( '/', $path );
		$filtered_params = array();

		for ( $i = 0; $i < count( $params ); $i++ ) {
			// if param belongs to black list skip it and its value
			if ( in_array( $params[ $i ], $this->black_list ) ) {
				$i++;
				continue;
			}

			$filtered_params[] = $params[ $i ];
		}

		$new_path = implode( '/', $filtered_params );
		if ( ! empty( $new_path ) ) {
			$new_path = trailingslashit( $new_path );
		}

		$url = str_replace( $path, $new_path, $url );


		return $url;
	}

	/**
	 * @param string $url
	 *
	 * @return string
	 */
	private function process_query( $url ) {
		$query = parse_url( $url, PHP_URL_QUERY );
		parse_str( $query, $output );
		$output = array_diff_key( $output, array_flip( $this->black_list ) );
		$new_query = http_build_query( $output );

		$url       = str_replace( $query, $new_query, $url );

		if ( '?' === $url[ strlen( $url ) - 1 ] ) {
			$url = rtrim( $url, '?' );
		}

		return $url;
	}
}
