<?php

class WPML_ST_Translations_Handle_Invalid_Strings {
	const MAX_ENTRIES_IN_LOG = 100;

	/**
	 * @var string
	 */
	private $option_name = 'wpml-st-persist-errors';

	/**
	 * @var array
	 */
	private $invalid_rows = array();

	/**
	 * @var WPML_Notices
	 */
	private $admin_notices;

	/**
	 * @var string
	 */
	private $notice_id = 'wpml-st-persist-errors';

	/**
	 * @var string
	 */
	private $notice_group = 'wpml-st-caching';

	/**
	 * @param WPML_Notices $admin_notices
	 */
	public function __construct( WPML_Notices $admin_notices = null ) {
		$this->admin_notices = $admin_notices;
	}

	/**
	 * @param array $row
	 */
	public function log_invalid_cached_translation( $row ) {
		$this->invalid_rows[] = $row;
	}

	public function store_invalid_records() {
		$currently_saved = get_option( $this->option_name );
		$currently_saved = $currently_saved ? $currently_saved : array();

		if ( count( $this->invalid_rows ) ) {
			$rows = array_merge( $currently_saved, $this->invalid_rows );
			$rows = array_splice( $rows, 0, self::MAX_ENTRIES_IN_LOG );

			update_option( $this->option_name, $rows );

			$this->display_notice();
		} else if ( 0 === count( $currently_saved ) && $this->admin_notices ) {
			$this->admin_notices->remove_notice( $this->notice_group, $this->notice_id );
		}

		$this->invalid_rows = array();
	}

	private function display_notice() {
		if ( $this->admin_notices ) {
			$msg = __( 'Something doesn\'t look right with "Caching of String Translation plugin". Please contact the WPML suppor', 'wpml-string-translation' );

			$notice = new WPML_Notice( $this->notice_id, $msg, $this->notice_group );
			$notice->set_css_class_types( 'warning' );
			$notice->set_hideable( true );
			$this->admin_notices->add_notice( $notice );
		}
	}
}